from scipy.stats import rankdata, norm
import pandas as pd

def INT(S, c):
    """
    Rank-based inverse normal transformation is a nonparametric transformation to 
    convert a sample distribution to the normal distribution.
    NaN values are ignored.

    Inputs:
    - S = pandas series 
    - c = Bloms constant

    Output:
    - transformed = normally distributed pandas series 
    """

    # Get rank, ties are averaged
    rank = rankdata(S, method="average")

    # Convert rank to normal distribution
    n = len(rank)
    transformed = norm.ppf((rank-c)/(n-2*c+1))

    return transformed


def INT_step(df, c=3.0/8):
    """
    Transforms all series in a dataframe using the rank-based inverse normal
    transformation.
    """

    # Initialize output DataFrame
    df_INT = pd.DataFrame(index=df.index)
    df_INT['t'] = df['t']

    # Process each column of the input dataframe
    for column in df.columns[1:]:
        df_INT[column] = INT(df[column], c)

    return df_INT
